@@ -1,5 +1,8 @@
 from .albert import *
 from .bert import *
+from .elmo import *
 from .labse import *
 from .use import *
-from .use_multi import *
\ No newline at end of file
+from .use_multi import *
+from .use_lite import *
+from .use import *
\ No newline at end of file
